@@ -1,4 +1,4 @@
 #!/bin/bash
 
 cd `dirname $0`/src
-./bluemindo.py
+./bluemindo.py "$@"
\ No newline at end of file
